==> dojo_1.5.0+dfsg.orig.tar.gz: dojo-release-1.5.0-src+dfsg/dojo/cldr/nls/el/gregorian.js <==
({
	"months-format-narrow": [
		"Ι", 
		"Φ", 
		"Μ", 
		"Α", 
		"Μ", 
		"Ι", 
		"Ι", 
		"Α", 
		"Σ", 
		"Ο", 
		"Ν", 
		"Δ"
	], 
	"field-weekday": "Ημέρα εβδομάδας", 
	"dateFormatItem-yyQQQQ": "QQQQ yy", 
	"dateFormatItem-yQQQ": "y QQQ", 
	"dateFormatItem-yMEd": "EEE, d/M/yyyy", 
	"dateFormatItem-MMMEd": "E, d MMM", 
	"eraNarrow": [
		"π.Χ.", 
		"μ.Χ."
	], 
	"dateFormat-long": "d MMMM y", 
	"months-format-wide": [
		"Ιανουαρίου", 
		"Φεβρουαρίου", 
		"Μαρτίου", 
		"Απριλίου", 
		"Μαΐου", 
		"Ιουνίου", 
		"Ιουλίου", 
		"Αυγούστου", 
		"Σεπτεμβρίου", 
		"Οκτωβρίου", 
		"Νοεμβρίου", 
		"Δεκεμβρίου"
	], 
	"dateFormatItem-EEEd": "EEE d", 
	"dayPeriods-format-wide-pm": "μ.μ.", 
	"dateFormat-full": "EEEE, d MMMM y", 
	"dateFormatItem-Md": "d/M", 
	"field-era": "Περίοδος", 
	"dateFormatItem-yM": "M/yyyy", 
	"months-standAlone-wide": [
		"Ιανουάριος", 
		"Φεβρουάριος", 
		"Μάρτιος", 
		"Απρίλιος", 
		"Μάιος", 
		"Ιούνιος", 
		"Ιούλιος", 
		"Αύγουστος", 
		"Σεπτέμβριος", 
		"Οκτώβριος", 
		"Νοέμβριος", 
		"Δεκέμβριος"
	], 
	"timeFormat-short": "h:mm a", 
	"quarters-format-wide": [
		"1ο τρίμηνο", 
		"2ο τρίμηνο", 
		"3ο τρίμηνο", 
		"4ο τρίμηνο"
	], 
	"timeFormat-long": "h:mm:ss a z", 
	"field-year": "Έτος", 
	"dateFormatItem-yMMM": "MMM y", 
	"dateFormatItem-yQ": "y Q", 
	"dateFormatItem-yyyyMMMM": "MMMM y", 
	"field-hour": "Ώρα", 
	"dateFormatItem-MMdd": "dd/MM", 
	"months-format-abbr": [
		"Ιαν", 
		"Φεβ", 
		"Μαρ", 
		"Απρ", 
		"Μαϊ", 
		"Ιουν", 
		"Ιουλ", 
		"Αυγ", 
		"Σεπ", 
		"Οκτ", 
		"Νοε", 
		"Δεκ"
	], 
	"dateFormatItem-yyQ": "Q yy", 
	"timeFormat-full": "h:mm:ss a zzzz", 
	"field-day-relative+0": "Σήμερα", 
	"field-day-relative+1": "Αύριο", 
	"field-day-relative+2": "Μεθαύριο", 
	"dateFormatItem-H": "HH", 
	"field-day-relative+3": "Σε τρεις ημέρες από τώρα", 
	"months-standAlone-abbr": [
		"Ιαν", 
		"Φεβ", 
		"Μαρ", 
		"Απρ", 
		"Μαϊ", 
		"Ιουν", 
		"Ιουλ", 
		"Αυγ", 
		"Σεπ", 
		"Οκτ", 
		"Νοε", 
		"Δεκ"
	], 
	"quarters-format-abbr": [
		"Τ1", 
		"Τ2", 
		"Τ3", 
		"Τ4"
	], 
	"quarters-standAlone-wide": [
		"1ο τρίμηνο", 
		"2ο τρίμηνο", 
		"3ο τρίμηνο", 
		"4ο τρίμηνο"
	], 
	"dateFormatItem-HHmmss": "HH:mm:ss", 
	"dateFormatItem-M": "L", 
	"days-standAlone-wide": [
		"Κυριακή", 
		"Δευτέρα", 
		"Τρίτη", 
		"Τετάρτη", 
		"Πέμπτη", 
		"Παρασκευή", 
		"Σάββατο"
	], 
	"dateFormatItem-MMMMd": "d MMMM", 
	"dateFormatItem-yyMMM": "MMM yy", 
	"timeFormat-medium": "h:mm:ss a", 
	"dateFormatItem-Hm": "HH:mm", 
	"quarters-standAlone-abbr": [
		"Τ1", 
		"Τ2", 
		"Τ3", 
		"Τ4"
	], 
	"eraAbbr": [
		"π.Χ.", 
		"μ.Χ."
	], 
	"field-minute": "Λεπτό", 
	"field-dayperiod": "π.μ./μ.μ.", 
	"days-standAlone-abbr": [
		"Κυρ", 
		"Δευ", 
		"Τρι", 
		"Τετ", 
		"Πεμ", 
		"Παρ", 
		"Σαβ"
	], 
	"dateFormatItem-d": "d", 
	"dateFormatItem-ms": "mm:ss", 
	"field-day-relative+-1": "Χθες", 
	"field-day-relative+-2": "Προχθές", 
	"field-day-relative+-3": "Πριν από τρεις ημέρες", 
	"dateFormatItem-MMMd": "d MMM", 
	"dateFormatItem-MEd": "E, d/M", 
	"dateFormatItem-yMMMM": "LLLL y", 
	"field-day": "Ημέρα", 
	"days-format-wide": [
		"Κυριακή", 
		"Δευτέρα", 
		"Τρίτη", 
		"Τετάρτη", 
		"Πέμπτη", 
		"Παρασκευή", 
		"Σάββατο"
	], 
	"field-zone": "Ζώνη", 
	"dateFormatItem-yyyyMM": "MM/yyyy", 
	"dateFormatItem-y": "y", 
	"months-standAlone-narrow": [
		"Ι", 
		"Φ", 
		"Μ", 
		"Α", 
		"Μ", 
		"Ι", 
		"Ι", 
		"Α", 
		"Σ", 
		"Ο", 
		"Ν", 
		"Δ"
	], 
	"dateFormatItem-yyMM": "MM/yy", 
	"days-format-abbr": [
		"Κυρ", 
		"Δευ", 
		"Τρι", 
		"Τετ", 
		"Πεμ", 
		"Παρ", 
		"Σαβ"
	], 
	"eraNames": [
		"π.Χ.", 
		"μ.Χ."
	], 
	"days-format-narrow": [
		"Κ", 
		"Δ", 
		"Τ", 
		"Τ", 
		"Π", 
		"Π", 
		"Σ"
	], 
	"field-month": "Μήνας", 
	"days-standAlone-narrow": [
		"Κ", 
		"Δ", 
		"Τ", 
		"Τ", 
		"Π", 
		"Π", 
		"Σ"
	], 
	"dateFormatItem-MMM": "LLL", 
	"dateFormatItem-HHmm": "HH:mm", 
	"dayPeriods-format-wide-am": "π.μ.", 
	"dateFormatItem-MMMMEd": "E, d MMMM", 
	"dateFormatItem-MMMMdd": "dd MMMM", 
	"dateFormat-short": "d/M/yy", 
	"field-second": "Δευτερόλεπτο", 
	"dateFormatItem-yMMMEd": "EEE, d MMM y", 
	"dateFormatItem-Ed": "E d", 
	"field-week": "Εβδομάδα", 
	"dateFormat-medium": "d MMM y", 
	"dateFormatItem-mmss": "mm:ss", 
	"dateFormatItem-yyyy": "y"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojo/cldr/nls/el/gregorian.js <==
define(
//begin v1.x content
{
	"months-format-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"field-weekday": "Ημέρα εβδομάδας",
	"dateFormatItem-yyQQQQ": "QQQQ yy",
	"dateFormatItem-yQQQ": "y QQQ",
	"dateFormatItem-yMEd": "EEE, d/M/yyyy",
	"dateFormatItem-MMMEd": "E, d MMM",
	"eraNarrow": [
		"π.Χ.",
		"μ.Χ."
	],
	"dateFormat-long": "d MMMM y",
	"months-format-wide": [
		"Ιανουαρίου",
		"Φεβρουαρίου",
		"Μαρτίου",
		"Απριλίου",
		"Μαΐου",
		"Ιουνίου",
		"Ιουλίου",
		"Αυγούστου",
		"Σεπτεμβρίου",
		"Οκτωβρίου",
		"Νοεμβρίου",
		"Δεκεμβρίου"
	],
	"dateFormatItem-EEEd": "EEE d",
	"dayPeriods-format-wide-pm": "μ.μ.",
	"dateFormat-full": "EEEE, d MMMM y",
	"dateFormatItem-Md": "d/M",
	"field-era": "Περίοδος",
	"dateFormatItem-yM": "M/yyyy",
	"months-standAlone-wide": [
		"Ιανουάριος",
		"Φεβρουάριος",
		"Μάρτιος",
		"Απρίλιος",
		"Μάιος",
		"Ιούνιος",
		"Ιούλιος",
		"Αύγουστος",
		"Σεπτέμβριος",
		"Οκτώβριος",
		"Νοέμβριος",
		"Δεκέμβριος"
	],
	"timeFormat-short": "h:mm a",
	"quarters-format-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"timeFormat-long": "h:mm:ss a z",
	"field-year": "Έτος",
	"dateFormatItem-yMMM": "LLL y",
	"dateFormatItem-yQ": "y Q",
	"dateFormatItem-yyyyMMMM": "LLLL y",
	"field-hour": "Ώρα",
	"dateFormatItem-MMdd": "dd/MM",
	"months-format-abbr": [
		"Ιαν",
		"Φεβ",
		"Μαρ",
		"Απρ",
		"Μαϊ",
		"Ιουν",
		"Ιουλ",
		"Αυγ",
		"Σεπ",
		"Οκτ",
		"Νοε",
		"Δεκ"
	],
	"dateFormatItem-yyQ": "Q yy",
	"timeFormat-full": "h:mm:ss a zzzz",
	"field-day-relative+0": "Σήμερα",
	"field-day-relative+1": "Αύριο",
	"field-day-relative+2": "Μεθαύριο",
	"dateFormatItem-H": "HH",
	"field-day-relative+3": "Σε τρεις ημέρες από τώρα",
	"months-standAlone-abbr": [
		"Ιαν",
		"Φεβ",
		"Μαρ",
		"Απρ",
		"Μαϊ",
		"Ιουν",
		"Ιουλ",
		"Αυγ",
		"Σεπ",
		"Οκτ",
		"Νοε",
		"Δεκ"
	],
	"quarters-format-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"quarters-standAlone-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"dateFormatItem-HHmmss": "HH:mm:ss",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"dateFormatItem-yyMMM": "LLL yy",
	"timeFormat-medium": "h:mm:ss a",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"eraAbbr": [
		"π.Χ.",
		"μ.Χ."
	],
	"field-minute": "Λεπτό",
	"field-dayperiod": "π.μ./μ.μ.",
	"days-standAlone-abbr": [
		"Κυρ",
		"Δευ",
		"Τρι",
		"Τετ",
		"Πεμ",
		"Παρ",
		"Σαβ"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "Χθες",
	"field-day-relative+-2": "Προχθές",
	"field-day-relative+-3": "Πριν από τρεις ημέρες",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"field-day": "Ημέρα",
	"days-format-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"field-zone": "Ζώνη",
	"dateFormatItem-yyyyMM": "MM/yyyy",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"dateFormatItem-yyMM": "MM/yy",
	"days-format-abbr": [
		"Κυρ",
		"Δευ",
		"Τρι",
		"Τετ",
		"Πεμ",
		"Παρ",
		"Σαβ"
	],
	"eraNames": [
		"π.Χ.",
		"μ.Χ."
	],
	"days-format-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"field-month": "Μήνας",
	"days-standAlone-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"dateFormatItem-MMM": "LLL",
	"dateFormatItem-HHmm": "HH:mm",
	"dayPeriods-format-wide-am": "π.μ.",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateFormatItem-MMMMdd": "dd MMMM",
	"dateFormat-short": "d/M/yy",
	"field-second": "Δευτερόλεπτο",
	"dateFormatItem-yMMMEd": "EEE, d MMM y",
	"dateFormatItem-Ed": "E d",
	"field-week": "Εβδομάδα",
	"dateFormat-medium": "d MMM y",
	"dateFormatItem-mmss": "mm:ss",
	"dateFormatItem-yyyy": "y"
}
//end v1.x content
);
